public class Parser extends BaseParser {
    public Parser(BaseLexer lexer) {
        super(lexer);
    }
    public void start() {
        try {
            long value = S();
            System.out.println("Computed value: " + value);
            String token = lookAhead(1);
            if (token != null) {
                throw new ParserErrorException("Parse error: '" + token + "' found while EOF is expected.");
            }
        } catch (ParserErrorException e) {
            System.err.println(e);
        }
    }
    public long S() throws ParserErrorException {
        long value = 0;
        String token = lookAhead(1);
        if (token == null) {
            throw new ParserErrorException("Parse error: EOF found while expecting '+' or '*'.");
        }
        switch (token) {
          case "+":
            readToken();
            value = A();
            value += A();
            break;
          case "*":
            readToken();
            value = A();
            value *= A();
            break;
          default:
            throw new ParserErrorException("Parse error at '" + token + "': tokens '+' or '*' not found.");
        }
        return value;
    }
    public long A() throws ParserErrorException {
        long value = 0;
        String token = lookAhead(1);
        if (token == null) {
            throw new ParserErrorException("Parse error: EOF found while expecting '+', '*', or a number.");
        }
        switch (token) {
          case "+":
          case "*":
            value = S();
            break;
          default:
            try {
                value = Long.parseLong(token);
            } catch (NumberFormatException e) {
                throw new ParserErrorException("Parse error at '" + token + "': Wrong number format.");
            }
            readToken();
            break;
        }
        return value;
    }
    public static void main(String[] args)
    {
        for (int i = 0; i < args.length; ++i) {
            System.out.println("Parsing: " + args[i]);
            Parser p = new Parser(new Lexer(args[i]));
            p.start();
        }
    }
}
